package controllers

import (
	"encoding/json"
	"hongze/hongze_clpt/models"
	"hongze/hongze_clpt/services"
	"strconv"
	"time"
)

// 微路演
type MicroRoadShowController struct {
	BaseAuthController
}

// @Title 视频详情
// @Description 时间线接口
// @Param   VideoId   query   int  true       "视频ID"
// @Success 200 {object} models.IndustryVideoDetailResp
// @router /detail [get]
func (this *MicroRoadShowController) Detail() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请重新登录"
		br.Ret = 408
		return
	}
	videoId, _ := this.GetInt("VideoId")
	videoSimple, au, err := services.GetindustryVideoDetailById(user, videoId)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取用户权限失败, Err: " + err.Error()
		return
	}
	resp := new(models.IndustryVideoDetailResp)
	resp.IndustryVideo = videoSimple
	resp.AuthInfo = au
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}

// @Title 记录用户浏览音频回放接口
// @Description 记录用户浏览音频回放接口
// @Param	request	body models.ActivityIdRep true "type json string"
// @Success Ret=200 {object} models.AddVideoHistoryReq
// @router /videoHistory/add [post]
func (this *MicroRoadShowController) VideoHistoryAdd() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请登录"
		br.ErrMsg = "请登录，用户信息为空"
		br.Ret = 408
		return
	}
	uid := user.UserId
	var req models.AddVideoHistoryReq
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &req)
	if err != nil {
		br.Msg = "参数解析异常！"
		br.ErrMsg = "参数解析失败，Err:" + err.Error()
		return
	}

	videoId := req.VideoId
	playSeconds := req.PlaySeconds

	var sellerName string
	sellerName, err = models.GetCompanySellerName(user.CompanyId)
	if err != nil {
		br.Msg = "报名失败！"
		br.ErrMsg = "获取对应销售失败，Err:" + err.Error()
		return
	}
	item := models.CygxMicroRoadshowVideoHistory{
		VideoId:     videoId,
		UserId:      uid,
		Mobile:      user.Mobile,
		Email:       user.Email,
		CompanyId:   user.CompanyId,
		CompanyName: user.CompanyName,
		RealName:    user.RealName,
		SellerName:  sellerName,
		PlaySeconds: strconv.Itoa(playSeconds),
		CreateTime:  time.Now(),
		ModifyTime:  time.Now(),
	}
	//if playSeconds != 0 {
	//	lastItem, err := models.GetLastCygxMicroRoadshowVideoHistory(videoId, user.UserId)
	//	if err != nil {
	//		br.Msg = "操作失败"
	//		br.ErrMsg = "操作失败,GetLastCygxMicroRoadshowVideoHistory Err:" + err.Error()
	//		return
	//	}
	//	err = models.UpdateLastCygxActivityVideoHistory(strconv.Itoa(playSeconds), lastItem.Id)
	//	if err != nil {
	//		br.Msg = "更新失败"
	//		br.ErrMsg = "更新失败,UpdateLastCygxActivityVideoHistory Err:" + err.Error()
	//		return
	//	}
	//} else {
	//	err = models.AddCygxMicroRoadshowVideoHistory(&item)
	//	if err != nil {
	//		br.Msg = "操作失败"
	//		br.ErrMsg = "操作失败,Err:" + err.Error()
	//		return
	//	}
	//	err = models.UpdateCygxActivityVideoCounts(videoId)
	//	if err != nil {
	//		br.Msg = "更新失败"
	//		br.ErrMsg = "更新失败,Err:" + err.Error()
	//		return
	//	}
	//}

	err = models.AddCygxMicroRoadshowVideoHistory(&item)
	if err != nil {
		br.Msg = "操作失败"
		br.ErrMsg = "操作失败,Err:" + err.Error()
		return
	}
	err = models.UpdateCygxActivityVideoCounts(videoId)
	if err != nil {
		br.Msg = "更新失败"
		br.ErrMsg = "更新失败,Err:" + err.Error()
		return
	}
	br.Ret = 200
	br.Success = true
	br.Msg = "操作成功"
	return
}
