package controllers

import (
	"encoding/json"
	"fmt"
	"github.com/rdlucklib/rdluck_tools/paging"
	"hongze/hongze_clpt/models"
	"hongze/hongze_clpt/services"
	"hongze/hongze_clpt/utils"
	"strconv"
	"strings"
	"time"
)

//报告
type ReportController struct {
	BaseAuthController
}

type ReportCommonController struct {
	BaseCommonController
}

type MobileReportController struct {
	BaseAuthMobileController
}

// @Title 行业报告分类列表接口
// @Description 获取行业报告分类列表接口
// @Param   ChartPermissionId   query   int  true       "分类ID"
// @Success 200 {object} models.TradeReportMappingResp
// @router /tradeList [get]
func (this *MobileReportController) TradeList() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请重新登录"
		br.Ret = 408
		return
	}
	fmt.Println(user)
	uid := user.UserId
	ChartPermissionId, _ := this.GetInt("ChartPermissionId")
	if ChartPermissionId < 1 {
		br.Msg = "请输入分类ID"
		return
	}
	//var result []*models.SearchItem
	var list []*models.TradeReportMapping
	var err error
	mapCategory := make(map[int]int)
	if ChartPermissionId == utils.CE_LUE_ID {
		listTrade, errTrade := models.GetReportMappingStrategyHomeAll()
		list = listTrade
		err = errTrade

		if user.Mobile != "" {
			//策略的处理
			categoryList, err := models.GetCygxXzsChooseCategoryList(user.Mobile)
			if err != nil && err.Error() != utils.ErrNoRow() {
				br.Msg = "获取信息失败"
				br.ErrMsg = "获取客户信息失败,Err:" + err.Error()
				return
			}
			for _, v := range categoryList {
				mapCategory[v.CategoryId] = v.CategoryId
			}
		}
	} else {
		listTrade, errTrade := models.GetTradeAll(ChartPermissionId)
		err = errTrade
		list = listTrade
	}

	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取品种信息失败,Err:" + err.Error()
		return
	}

	for k, v := range list {
		list[k].UpdateTime = utils.TimeRemoveHms(v.UpdateTime)
		count, err := models.CheckThisCategoryNewArticleIsRead(uid, v.CategoryId)
		if err != nil {
			br.Msg = "获取信息失败"
			br.ErrMsg = "获取帖子总数失败，Err:" + err.Error()
			return
		}
		if count == 0 && user.CreatedTime.Before(utils.StrTimeToTime(v.UpdateTime)) && utils.StrTimeToTime(utils.OnlineTime).Before(utils.StrTimeToTime(v.UpdateTime)) {
			list[k].IsRed = true
		}
		var condition string
		var pars []interface{}
		condition = " AND  a.category_id_two =  " + strconv.Itoa(v.CategoryId)
		if ChartPermissionId != utils.CE_LUE_ID {
			var pageSize int
			if ChartPermissionId == utils.KE_JI_ID {
				pageSize = 12
			} else {
				pageSize = 3
			}
			listArticle, err := models.GetHomeList(condition, pars, 0, pageSize)
			if err != nil {
				br.Msg = "获取信息失败"
				br.Msg = "GetHomeList，Err:" + err.Error()
				return
			}
			list[k].ListArticle = listArticle
		} else {
			if mapCategory[v.CategoryId] > 0 {
				list[k].IsFollow = true
			}
			list[k].ListArticle = make([]*models.HomeArticle, 0)
		}
	}
	resp := new(models.TradeReportMappingResp)

	if len(list) == 0 {
		list = make([]*models.TradeReportMapping, 0)
	}
	resp.List = list
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}

// @Title 产业报告分类列表接口
// @Description 获取产业报告分类列表接口
// @Param   ChartPermissionId   query   int  true       "分类ID"
// @Param   DeepCover   query   int  false       "是否选择深度覆盖，1是，0否 不填默认为0"
// @Param   RecommendFocus   query   int  false       "是否选择推荐关注，1是，0否 不填默认为0"
// @Param   PageSize   query   int  true       "每页数据条数"
// @Param   CurrentIndex   query   int  true       "当前页页码，从1开始"
// @Param   IsBillboard   query   bool  false       "是否属于榜单 是true 否 false"
// @Success 200 {object} models.IndustrialManagementList
// @router /industryList [get]
func (this *MobileReportController) IndustryList() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请重新登录"
		br.Ret = 408
		return
	}
	uid := user.UserId
	ChartPermissionId, _ := this.GetInt("ChartPermissionId")
	orderColumn := this.GetString("OrderColumn")
	orderColumnNew := this.GetString("OrderColumn")
	isNewLabel := this.GetString("IsNewLabel")
	isDeepLabel := this.GetString("IsDeepLabel")
	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")
	deepCover, _ := this.GetInt("DeepCover")
	recommendFocus, _ := this.GetInt("RecommendFocus")
	isBillboard, _ := this.GetBool("IsBillboard", false)
	var orderSrt string
	var condition string
	var startSize int
	resp := new(models.IndustrialManagementList)
	if pageSize <= 0 {
		pageSize = utils.PageSize20
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}

	if isBillboard {
		pageSize = utils.PageSize15
		currentIndex = 1
	}

	startSize = paging.StartIndex(currentIndex, pageSize)
	if ChartPermissionId > 0 {
		condition += ` AND man.chart_permission_id IN (` + strconv.Itoa(ChartPermissionId) + `)`
	}

	// 获取近一个月产业报告阅读次数最多的产业
	var topCond string
	var topPars []interface{}
	topReadIndustryId := 0
	if ChartPermissionId > 0 {
		topCond += ` AND chart_permission_id = ?`
		topPars = append(topPars, ChartPermissionId)
	}
	topReadIndustry, e := models.GetTopOneMonthArtReadNumIndustry(topCond, topPars)
	if e != nil && e.Error() != utils.ErrNoRow() {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取近一个月报告阅读次数最多的产业失败, Err: " + e.Error()
		return
	}
	if topReadIndustry != nil {
		topReadIndustryId = topReadIndustry.IndustrialManagementId
	}
	// 深度覆盖
	if deepCover == 1 {
		// 查询深标签产业报告数
		var deepCondition string
		var deepPars []interface{}
		deepCondition += ` AND man.is_deep_label = 1`
		if ChartPermissionId > 0 {
			deepCondition += ` AND man.chart_permission_id = ?`
			deepPars = append(deepPars, ChartPermissionId)
		}
		industryCountList, e := models.GetIndustryArtCountByCondition(deepCondition, deepPars)
		if e != nil {
			br.Msg = "获取信息失败"
			br.ErrMsg = "获取深标签产业报告数失败, Err: " + e.Error()
			return
		}
		deepIdArr := make([]string, 0)
		for i := range industryCountList {
			if industryCountList[i].ArtNum > 10 {
				deepIdArr = append(deepIdArr, strconv.Itoa(industryCountList[i].IndustrialManagementId))
			}
		}
		deepIds := strings.Join(deepIdArr, ",")
		if deepIds != "" {
			condition = `AND man.industrial_management_id IN (` + deepIds + `)`
		}
	}
	// 推荐关注
	if recommendFocus == 1 {
		condition += ` AND man.recommended_index >= 80`
	}

	var list []*models.IndustrialManagement
	total, err := models.GetIndustrialManagementAllCount(condition)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取数量失败,Err:" + err.Error()
		return
	}

	if orderColumn == "" {
		orderColumn = "NewTime"
	}
	if orderColumn == "NewTime" {
		orderSrt = "update_time DESC"
	} else {
		orderSrt = "man.recommended_index DESC,update_time DESC"
	}
	if ChartPermissionId == 0 {
		ChartPermissionId = 20
	}

	list, err = models.GetIndustrialManagementAll(uid, condition, orderSrt, startSize, pageSize, isBillboard)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取品种信息失败,Err:" + err.Error()
		return
	}
	list, err = services.HandleIndustryList(list, user)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取信息失败,Err:" + err.Error()
		return
	}
	industrialIdArr := make([]int, 0)
	for k, v := range list {
		industrialIdArr = append(industrialIdArr, v.IndustrialManagementId)
		if topReadIndustryId > 0 && list[k].IndustrialManagementId == topReadIndustryId {
			list[k].IsHot = true
		}
	}
	if orderColumnNew != "" {
		item := new(models.CygxReportIndustrialSeaarchHistory)
		item.UserId = user.UserId
		item.Mobile = user.Mobile
		item.CompanyId = user.CompanyId
		item.CompanyName = user.CompanyName
		item.CreateTime = time.Now()
		item.IsDeepLabel = isDeepLabel
		item.IsNewLabel = isNewLabel
		item.ChartPermissionId = ChartPermissionId
		if orderColumnNew == "NewTime" {
			item.OrderColumn = "0"
		} else {
			item.OrderColumn = "1"
		}
		go models.AddCygxReportIndustrialSeaarchHistory(item)
	}
	if len(list) == 0 {
		list = make([]*models.IndustrialManagement, 0)
	}
	page := paging.GetPaging(currentIndex, pageSize, total)
	if isBillboard {
		total = len(list)
	}
	resp.List = list
	resp.Paging = page
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}

// @Title 产业下所关联的文章分类列表
// @Description 产业下所关联的文章分类列表接口
// @Param   IndustrialManagementId   query   int  true       "产业ID"
// @Success 200 {object} models.IndustrialToArticleCategoryListRep
// @router /toArticleCategoryList [get]
func (this *MobileReportController) ArticleCategoryList() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请重新登录"
		br.Ret = 408
		return
	}
	uid := user.UserId
	industrialManagementId, _ := this.GetInt("IndustrialManagementId")
	if industrialManagementId < 1 {
		br.Msg = "请输入分类ID"
		return
	}

	detail, err := models.GetIndustrialManagementDetail(industrialManagementId)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取信息失败,Err:" + err.Error()
		return
	}
	list, err := models.IndustrialToArticleCategory(industrialManagementId, detail.ChartPermissionId)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取品种信息失败,Err:" + err.Error()
		return
	}

	for k, v := range list {
		recordCount, err := models.IndustrialUserRecordArticleCount(uid, industrialManagementId, v.CategoryId)
		if err != nil && err.Error() != utils.ErrNoRow() {
			br.Msg = "获取信息失败"
			br.ErrMsg = "判断是否已申请过试用失败，Err:" + err.Error()
			return
		}
		Newdetail, err := models.GetNewIndustrialUserRecordArticle(industrialManagementId, v.CategoryId)
		if err != nil {
			br.Msg = "获取信息失败"
			br.ErrMsg = "获取信息失败,Err:" + err.Error()
			return
		}
		if recordCount == 0 && user.CreatedTime.Before(utils.StrTimeToTime(Newdetail.PublishDate)) && utils.StrTimeToTime(utils.OnlineTime).Before(utils.StrTimeToTime(Newdetail.PublishDate)) {
			list[k].IsRed = true
		}
	}
	//标的列表
	industrialSubjectList, err := models.GetIndustrialSubjectAll(industrialManagementId)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取品种信息失败,Err:" + err.Error()
		return
	}
	videoSimple, au, err := services.GetindustryVideo(user, industrialManagementId)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取用户权限失败, Err: " + err.Error()
		return
	}
	timeLineItem := models.IndustrialToArticleCategoryRep{
		CategoryId:    utils.TIME_CATEGORYID,
		MatchTypeName: "时间线",
	}
	list = append([]*models.IndustrialToArticleCategoryRep{&timeLineItem}, list...)
	resp := new(models.IndustrialToArticleCategoryListRep)
	resp.List = list
	resp.ListSubject = industrialSubjectList
	resp.LayoutTime = utils.TimeRemoveHms(detail.LayoutTime)
	resp.IndustryName = detail.IndustryName
	resp.IndustrialManagementId = industrialManagementId
	if videoSimple != nil && videoSimple.Id > 0 {
		resp.IndustryVideo = videoSimple
	}
	resp.AuthInfo = au
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}

// @Title 根据行业分类获取文章列表
// @Description根据行业分类获取文章列表接口
// @Param   PageSize   query   int  true       "每页数据条数"
// @Param   CurrentIndex   query   int  true       "当前页页码，从1开始"
// @Param   CategoryId   query   int  true       "分类ID"
// @Param   IndustrialManagementId   query   int  false       "产业ID"
// @Success 200 {object} models.TacticsListResp
// @router /articleList/byCategoryId [get]
func (this *MobileReportController) List() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请重新登录"
		br.Ret = 408
		return
	}
	//uid := user.UserId
	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")
	categoryId, _ := this.GetInt("CategoryId")
	industrialManagementId, _ := this.GetInt("IndustrialManagementId")

	var startSize int
	if pageSize <= 0 {
		pageSize = utils.PageSize20
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}
	startSize = paging.StartIndex(currentIndex, pageSize)
	var condition string
	var pars []interface{}
	var total int
	resp := new(models.TacticsListResp)
	page := paging.GetPaging(currentIndex, pageSize, total)
	list := make([]*models.HomeArticle, 0)

	if categoryId == utils.TIME_CATEGORYID {
		var err error
		list, total, err = models.GetTimeLineReportIndustrialList(industrialManagementId, startSize, pageSize)
		if err != nil {
			br.Msg = "获取信息失败"
			br.ErrMsg = "获取产业报告+晨会点评列表,Err:" + err.Error()
			return
		}
	} else {
		//获取该产业下所对应的行业图片
		detail, errCategory := models.GetdetailByCategoryIdOne(categoryId)
		if errCategory != nil {
			br.Msg = "获取信息失败"
			br.ErrMsg = "获取信息失败,Err:" + errCategory.Error() + "categoryID 不存在：" + strconv.Itoa(categoryId)
			return
		}
		//对应行业的图片
		detailChartPermissionUrl, err := models.GetConfigByCode("category_chart_permissionimg_url")
		if err != nil {
			br.Msg = "获取数据失败"
			br.ErrMsg = "行业配置信息失败，Err:" + err.Error()
			return
		}
		chartPermissionUrlList := strings.Split(detailChartPermissionUrl.ConfigValue, "{|}")
		mapChartPermission := make(map[string]string)
		var permissionName string
		var imgUrlChartPermission string
		for _, v := range chartPermissionUrlList {
			vslice := strings.Split(v, "_")
			permissionName = vslice[0]
			imgUrlChartPermission = vslice[len(vslice)-1]
			mapChartPermission[permissionName] = imgUrlChartPermission
		}

		//对应分类的所图片
		detailCategoryUrl, err := models.GetConfigByCode("category_map_img_url")
		if err != nil {
			br.Msg = "获取数据失败"
			br.ErrMsg = "行业配置信息失败，Err:" + err.Error()
			return
		}
		categoryUrlList := strings.Split(detailCategoryUrl.ConfigValue, "{|}")
		mapCategoryUrl := make(map[string]string)
		var categoryIdStr string
		var imgUrlChart string
		for _, v := range categoryUrlList {
			vslice := strings.Split(v, "_")
			categoryIdStr = vslice[0]
			imgUrlChart = vslice[len(vslice)-1]
			mapCategoryUrl[categoryIdStr] = imgUrlChart
		}
		condition += ` AND category_id_two=? `
		pars = append(pars, categoryId)

		if industrialManagementId > 0 {
			industrialManageentList, err := models.GetIndustrialArticleGroupManagementByIndustrialManagementId(industrialManagementId)
			if err != nil {
				br.Msg = "获取信息失败"
				br.Msg = "获取产业关联的文章ID失败，GetIndustrialArticleGroupManagementByIndustrialManagementIdErr:" + err.Error()
				return
			}
			articleIdList := make([]string, 0)
			for _, v := range industrialManageentList {
				articleIdList = append(articleIdList, strconv.Itoa(v.ArticleId))
			}
			condition += ` AND a.article_id IN (  ` + utils.GetOrmInReplace(len(articleIdList)) + ` )  `
			pars = append(pars, articleIdList)
		}

		total, err = models.GetHomeCount(condition, pars)
		if err != nil {
			br.Msg = "获取信息失败"
			br.Msg = "获取帖子总数失败，Err:" + err.Error()
			return
		}

		list, err = models.GetHomeList(condition, pars, startSize, pageSize)
		if err != nil {
			br.Msg = "获取信息失败"
			br.Msg = "获取帖子数据失败，Err:" + err.Error()
			return
		}
		for k, v := range list {
			list[k].ImgUrlPc = mapCategoryUrl[v.CategoryId]
		}
		if categoryId > 0 {
			detail, errCategory := models.GetdetailByCategoryId(categoryId)
			if errCategory != nil {
				br.Msg = "获取信息失败"
				br.ErrMsg = "获取信息失败,Err:" + errCategory.Error() + "categoryID 不存在：" + strconv.Itoa(categoryId)
				return
			}
			resp.MatchTypeName = detail.MatchTypeName
		}
		resp.CategoryImgUrlPc = mapChartPermission[detail.ChartPermissionName]
	}
	lenList := len(list)
	for i := 0; i < lenList; i++ {
		item := list[i]
		list[i].Body = ""
		list[i].Abstract, _ = services.GetReportContentTextSub(item.Abstract)
		list[i].Annotation, _ = services.GetReportContentTextSub(item.Annotation)
		list[i].PublishDate = utils.StrTimeToTime(item.PublishDate).Format(utils.FormatDate) //时间字符串格式转时间格式
		//行业比较研究、资金流向，显示报告的摘要
		if resp.MatchTypeName == "行业比较研究" || resp.MatchTypeName == "资金流向" {
			list[i].Annotation = list[i].Abstract
		}
	}
	if len(list) == 0 {
		list = make([]*models.HomeArticle, 0)
	}
	page = paging.GetPaging(currentIndex, pageSize, total)
	resp.List = list
	resp.Paging = page
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}

// @Title 产业关注/取消关注
// @Description 产业关注/取消关注 接口
// @Param	request	body models.CygxIndustryFllowRep true "type json string"
// @Success 200
// @router /industrial/fllow [post]
func (this *ReportController) IndustrialFllow() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请重新登录"
		br.Ret = 408
		return
	}
	uid := user.UserId
	var req models.CygxIndustryFllowRep
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &req)
	if err != nil {
		br.Msg = "参数解析异常！"
		br.ErrMsg = "参数解析失败，Err:" + err.Error()
		return
	}
	industrialManagementId := req.IndustrialManagementId
	var condition string
	countIndustrial, err := models.GetIndustrialManagementCount(industrialManagementId)
	if err != nil {
		br.Msg = "获取数据失败！"
		br.ErrMsg = "获取数据失败，Err:" + err.Error()
		return
	}
	if countIndustrial == 0 {
		br.Msg = "产业不存在！"
		br.ErrMsg = "产业ID不存在:" + strconv.Itoa(industrialManagementId)
		return
	}
	count, err := models.GetCountCygxIndustryFllow(industrialManagementId, user.Mobile, condition)
	if err != nil {
		br.Msg = "获取数据失败！"
		br.ErrMsg = "获取数据失败，Err:" + err.Error()
		return
	}
	resp := new(models.CygxIndustryFllowResp)
	if count == 0 {
		item := new(models.CygxIndustryFllow)
		item.IndustrialManagementId = industrialManagementId
		item.UserId = uid
		item.Email = user.Email
		item.Mobile = user.Mobile
		item.RealName = user.RealName
		item.CompanyId = user.CompanyId
		item.CompanyName = user.CompanyName
		item.Type = 1
		item.CreateTime = time.Now()
		item.ModifyTime = time.Now()
		_, err = models.AddCygxIndustryFllow(item)
		if err != nil {
			br.Msg = "操作失败"
			br.ErrMsg = "操作失败,Err:" + err.Error()
			return
		}
		resp.Status = 1
		br.Msg = "关注成功"
	} else {
		err = models.RemoveCygxIndustryFllow(uid, industrialManagementId)
		if err != nil {
			br.Msg = "操作失败"
			br.ErrMsg = "取消关注失败,Err:" + err.Error()
			return
		}
		resp.Status = 2
		br.Msg = "已取消关注"
	}
	//处理是否关注全部赛道字段
	go services.IndustryFllowWithTrack(industrialManagementId, count, uid)
	br.Ret = 200
	br.Success = true
	br.Data = resp
}

// @Title 行业关注/取消关注
// @Description 行业关注/取消关注 接口
// @Param	request	body models.CygxCategoryFllowRep true "type json string"
// @Success 200
// @router /category/fllow [post]
func (this *ReportController) CategoryFllow() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请重新登录"
		br.Ret = 408
		return
	}
	uid := user.UserId
	var req models.CygxCategoryFllowRep
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &req)
	if err != nil {
		br.Msg = "参数解析异常！"
		br.ErrMsg = "参数解析失败，Err:" + err.Error()
		return
	}
	categoryId := req.CategoryId
	var condition string
	countCategory, err := models.GetCategoryCount(categoryId)
	if err != nil {
		br.Msg = "获取数据失败！"
		br.ErrMsg = "获取数据失败，Err:" + err.Error()
		return
	}
	if countCategory == 0 {
		br.Msg = "产业不存在！"
		br.ErrMsg = "产业ID不存在:" + strconv.Itoa(categoryId)
		return
	}
	count, err := models.GetCountCategoryFllow(categoryId, user.Mobile, condition)
	if err != nil {
		br.Msg = "获取数据失败！"
		br.ErrMsg = "获取数据失败，Err:" + err.Error()
		return
	}
	resp := new(models.CygxIndustryFllowResp)
	if count == 0 {
		item := new(models.CygxXzsChooseCategory)
		item.CategoryId = categoryId
		item.UserId = uid
		item.Email = user.Email
		item.Mobile = user.Mobile
		item.RealName = user.RealName
		item.CompanyId = user.CompanyId
		item.CompanyName = user.CompanyName
		item.CreateTime = time.Now()
		item.ModifyTime = time.Now()
		_, err = models.AddCygxCategoryFllow(item)
		if err != nil {
			br.Msg = "操作失败"
			br.ErrMsg = "操作失败,Err:" + err.Error()
			return
		}
		resp.Status = 1
		br.Msg = "关注成功"
	} else {
		err = models.RemoveCygxCategoryFllow(user.Mobile, categoryId)
		if err != nil {
			br.Msg = "操作失败"
			br.ErrMsg = "取消关注失败,Err:" + err.Error()
			return
		}
		resp.Status = 2
		br.Msg = "已取消关注"
	}
	br.Ret = 200
	br.Success = true
	br.Data = resp
}

// @Title 报告搜索
// @Description 报告搜索接口
// @Param   PageSize   query   int  true       "每页数据条数"
// @Param   CurrentIndex   query   int  true       "当前页页码，从1开始"
// @Param   KeyWord   query   string  true       "搜索关键词"
// @Success 200 {object} models.ReoprtSearchResp
// @router /searchReport [get]
func (this *MobileReportController) SearchReport() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请重新登录"
		br.Ret = 408
		return
	}
	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")
	keyWord := this.GetString("KeyWord")
	var condition string
	var conditionSql string
	//var sqlGroup string
	var total int
	var startSize int
	if pageSize <= 0 {
		pageSize = utils.PageSize20
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}
	startSize = paging.StartIndex(currentIndex, pageSize)
	page := paging.GetPaging(currentIndex, pageSize, total)
	resp := new(models.ReoprtSearchResp)
	//匹配报告标题、
	condition = ` AND ( a.title LIKE '%` + keyWord + `%' OR  a.body LIKE '%` + keyWord + `%') AND a.publish_status = 1 `

	conditionSql = ` AND a.article_id <  ` + strconv.Itoa(utils.SummaryArticleId) + condition + ` OR ( article_type = 'lyjh' ` + condition + ` ) `
	total, err := models.GetReoprtSearchCount(conditionSql)
	if err != nil {
		br.Msg = "获取信息失败"
		br.Msg = "获取总数失败，Err:" + err.Error()
		return
	}
	//listHz, err := models.GetReoprtSearchList(` AND a.article_id <  `+strconv.Itoa(utils.SummaryArticleId)+condition+` OR ( article_type = 'lyjh' `+condition+` ) `+sqlGroup, user.UserId, startSize, pageSize)
	listHz, err := models.GetReoprtSearchList(conditionSql, user.UserId, startSize, pageSize)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取文章列表失败,Err:" + err.Error()
		return
	}
	for k, _ := range listHz {
		listHz[k].Source = 1
	}
	var articleIds string
	for _, v := range listHz {
		articleIds += strconv.Itoa(v.ArticleId) + ","
	}
	articleIds = strings.TrimRight(articleIds, ",")
	silcearticleIds := strings.Split(articleIds, ",")
	//获取文章关联的产业
	var pars []interface{}
	pars = make([]interface{}, 0)
	articleIdList := make([]string, 0)
	for _, v := range silcearticleIds {
		articleIdList = append(articleIdList, v)
	}
	condition = ` AND mg.article_id IN (  ` + utils.GetOrmInReplace(len(silcearticleIds)) + ` )  `
	pars = append(pars, articleIdList)
	industrialList, err := models.GetIndustrialListByarticleId(pars, condition)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取失败，GetSubjectList Err:" + err.Error()
		return
	}
	industrialMap := make(map[int][]*models.IndustrialManagementResp)
	if len(industrialList) > 0 {
		for _, v := range industrialList {
			item := new(models.IndustrialManagementResp)
			//item.ArticleId = v.ArticleId
			item.IndustrialManagementId = v.IndustrialManagementId
			item.IndustryName = v.IndustryName
			item.ChartPermissionId = v.ChartPermissionId
			industrialMap[v.ArticleId] = append(industrialMap[v.ArticleId], item)
		}
	}

	detailCategoryUrl, err := models.GetConfigByCode("category_map_img_url")
	if err != nil {
		br.Msg = "获取数据失败"
		br.ErrMsg = "行业配置信息失败，Err:" + err.Error()
		return
	}
	categoryUrlList := strings.Split(detailCategoryUrl.ConfigValue, "{|}")
	mapCategoryUrl := make(map[string]string)
	var categoryId string
	var imgUrlChart string
	for _, v := range categoryUrlList {
		vslice := strings.Split(v, "_")
		categoryId = vslice[0]
		imgUrlChart = vslice[len(vslice)-1]
		mapCategoryUrl[categoryId] = imgUrlChart
	}

	for k, v := range listHz {
		if len(industrialMap[v.ArticleId]) > 0 {
			listHz[k].List = industrialMap[v.ArticleId]
		} else {
			listHz[k].List = make([]*models.IndustrialManagementResp, 0)
		}
		listHz[k].Body = ""
		listHz[k].Abstract, _ = services.GetReportContentTextSub(v.Abstract)
		listHz[k].Annotation, _ = services.GetReportContentTextSub(v.Annotation)
		//行业比较研究、资金流向，显示报告的摘要
		if listHz[k].CategoryName == "行业比较研究" || listHz[k].CategoryName == "资金流向" {
			listHz[k].Annotation = listHz[k].Abstract
		}
		listHz[k].ImgUrlPc = mapCategoryUrl[v.CategoryId]
	}

	if keyWord != "" {
		go services.AddUserSearchLog(user, keyWord, 5)
	}
	if len(listHz) == 0 {
		listHz = make([]*models.ArticleCollectionResp, 0)
	}

	page = paging.GetPaging(currentIndex, pageSize, total)

	resp.Paging = page
	resp.ListHz = listHz
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}

// @Title 资源包搜索
// @Description 资源包搜索接口
// @Param   KeyWord   query   string  true       "搜索关键词"
// @Success 200 {object} models.SearchResourceResp
// @router /searchResource [get]
func (this *MobileReportController) SearchResource() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请重新登录"
		br.Ret = 408
		return
	}
	uid := user.UserId
	fllowList, err := models.GetUserFllowIndustrialList(uid)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取失败，GetUserFllowIndustrialList Err:" + err.Error()
		return
	}
	fllowMap := make(map[int]int)
	if len(fllowList) > 0 {
		for _, v := range fllowList {
			fllowMap[v.IndustrialManagementId] = v.IndustrialManagementId
		}
	}
	keyWord := this.GetString("KeyWord")
	var condition string
	var conditionOr string
	conditionOr += `  OR ( m.subject_names LIKE '%` + keyWord + `%' AND a.article_id < ` + strconv.Itoa(utils.SummaryArticleId) + `  AND publish_status = 1 ) `
	condition = ` AND m.industry_name LIKE '%` + keyWord + `%' AND a.article_id < ` + strconv.Itoa(utils.SummaryArticleId) + conditionOr

	listHz, err := models.GetSearchResourceList(condition)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取品种信息失败,Err:" + err.Error()
		return
	}
	//合并产业关联的标的
	listSubjcet, err := models.GetThemeHeatSubjectList("")
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取标的信息失败,Err:" + err.Error()
		return
	}
	industrialIdArr := make([]int, 0)
	for k, v := range listHz {
		listHz[k].Source = 1
		if fllowMap[v.IndustrialManagementId] > 0 {
			listHz[k].IsFollow = true
		}
		industrialIdArr = append(industrialIdArr, v.IndustrialManagementId)
	}

	if len(industrialIdArr) > 0 {
		//合并产业关联的标的
		listSubjcet, err = models.GetIndustrialSubjectAllByIndustrialId(industrialIdArr)
		if err != nil {
			br.Msg = "获取信息失败"
			br.ErrMsg = "获取标的信息失败,Err:" + err.Error()
			return
		}
		mapIndustrial := make(map[string]int)
		for _, v := range listSubjcet {
			for k2, v2 := range listHz {
				if v2.IndustrialManagementId == v.IndustrialManagementId && mapIndustrial[fmt.Sprint(v2.IndustrialManagementId, "Hz", v.SubjectName)] == 0 {
					listHz[k2].IndustrialSubjectList = append(listHz[k2].IndustrialSubjectList, v)
					mapIndustrial[fmt.Sprint(v2.IndustrialManagementId, "Hz", v.SubjectName)] = v2.IndustrialManagementId
				}
			}
		}
	}

	mapUPdateTime := make(map[int]string)
	articleIdArr := make([]int, 0)
	//获取这些产业下最新更新的文章
	fmt.Println(industrialIdArr)
	listUpdateTime, err := models.GetNewArticleDetailByIndustrialIds(industrialIdArr)
	if err != nil && err.Error() != utils.ErrNoRow() {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取信息失败 GetNewArticleDetailByIndustrialIds ,Err:" + err.Error()
		return
	}
	for _, v := range listUpdateTime {
		mapUPdateTime[v.IndustrialManagementId] = v.PublishDate
		articleIdArr = append(articleIdArr, v.ArticleId)
	}
	for k, v := range listHz {
		listHz[k].UpdateTime = utils.TimeRemoveHms(mapUPdateTime[v.IndustrialManagementId])
	}

	if keyWord != "" {
		go services.AddUserSearchLog(user, keyWord, 4)
	}
	resp := new(models.SearchResourceResp)
	if len(listHz) == 0 {
		listHz = make([]*models.IndustrialManagement, 0)
	}
	resp.ListHz = listHz
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}

// @Title 报告搜索、资源包搜索接口
// @Description 报告搜索、资源包搜索接口接口
// @Param   KeyWord   query   string  true       "搜索关键词"
// @Param   PageSize   query   int  true       "每页数据条数"
// @Param   CurrentIndex   query   int  true       "当前页页码，从1开始"
// @Param   SearchType   query   int  true       "1：综合，2：全部"
// @Success 200 {object} models.SearchReportAndResourceResp
// @router /searchReportAndResource [get]
func (this *MobileReportController) SearchReportAndResource() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请重新登录"
		br.Ret = 408
		return
	}
	//uid := user.UserId
	keyWord := this.GetString("KeyWord")
	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")
	searchType, _ := this.GetInt("SearchType")
	var total int
	var startSize int
	if pageSize <= 0 {
		pageSize = utils.PageSize20
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}
	startSize = paging.StartIndex(currentIndex, pageSize)
	page := paging.GetPaging(currentIndex, pageSize, total)
	var condition string
	var conditionSql string
	//匹配报告标题、
	condition = ` AND ( a.title LIKE '%` + keyWord + `%' OR  a.body LIKE '%` + keyWord + `%') AND a.publish_status = 1 `
	conditionSql = ` AND a.article_id <  ` + strconv.Itoa(utils.SummaryArticleId) + condition + ` OR ( article_type = 'lyjh' ` + condition + ` ) `
	total, err := models.GetReoprtSearchCount(conditionSql)
	if err != nil {
		br.Msg = "获取信息失败"
		br.Msg = "获取总数失败，Err:" + err.Error()
		return
	}
	if searchType == 1 {
		pageSize = utils.PageSize5
	}
	ListHzReport, err := services.GetReoprtSearchListHz(conditionSql, user.UserId, startSize, pageSize)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取失败，GetReoprtSearchListHz Err:" + err.Error()
		return
	}
	if len(ListHzReport) == 0 {
		ListHzReport = make([]*models.ArticleCollectionResp, 0)
	}
	var conditionOr string
	conditionOr += ` OR ( m.subject_names LIKE '%` + keyWord + `%' AND a.article_id < ` + strconv.Itoa(utils.SummaryArticleId) + `  AND publish_status = 1 ) `
	condition = ` AND m.industry_name LIKE '%` + keyWord + `%' AND a.article_id < ` + strconv.Itoa(utils.SummaryArticleId) + conditionOr
	listHzResource, err := services.GetSearchResourceListHz(condition, user)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取品种信息失败,Err:" + err.Error()
		return
	}
	resp := new(models.SearchReportAndResourceResp)
	if len(listHzResource) == 0 {
		listHzResource = make([]*models.IndustrialManagement, 0)
	}
	if keyWord != "" {
		go services.AddUserSearchLog(user, keyWord, 5)
	}
	page = paging.GetPaging(currentIndex, pageSize, total)
	resp.Paging = page
	resp.ListHzResource = listHzResource
	resp.ListHzReport = ListHzReport
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}

// @Title 公司速览
// @Description 公司速览接口
// @Param   ChartPermissionId   query   int  false       "分类ID"
// @Success 200 {object} models.ArticleDataLogoListResp
// @router /companyList [get]
func (this *ReportCommonController) CompanyList() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	var condition string
	var pars []interface{}
	chartPermissionId, _ := this.GetInt("ChartPermissionId")
	if chartPermissionId > 1 {
		categoryId, err := models.GetCategoryId(chartPermissionId)
		if err != nil && err.Error() != utils.ErrNoRow() {
			br.Msg = "获取信息失败"
			br.ErrMsg = "获取分类权限信息失败，Err:" + err.Error()
			return
		}
		if categoryId != "" {
			condition += ` AND a.category_id IN  (` + categoryId + `)`
		}
	}
	condition += ` 	AND a.type_name = '综述报告'   ORDER BY  a.modify_time_by_cl DESC  `
	list, err := models.CygxArticleDataList(condition, pars)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取报告封面图片失败, Err:" + err.Error()
		return
	}
	listLogo := make([]*models.ArticleDataLogoResp, 0)
	for i := range list {
		v := list[i]
		comapnyList := services.HandleArticleStock(v.Stock)
		if len(comapnyList) > 1 {
			for kC, vC := range comapnyList {
				sliceCovers := strings.Split(v.Cover, "{|}")
				cover := v.Cover
				if len(sliceCovers) == len(comapnyList) {
					cover = sliceCovers[kC]
				}
				listLogo = append(listLogo, &models.ArticleDataLogoResp{
					ArticleId:   v.ArticleId,
					Cover:       cover,
					ComapnyList: services.HandleArticleStock(vC.ComapnyName),
				})
			}
		} else {
			listLogo = append(listLogo, &models.ArticleDataLogoResp{
				ArticleId:   v.ArticleId,
				Cover:       v.Cover,
				ComapnyList: services.HandleArticleStock(v.Stock),
			})
		}

	}
	resp := new(models.ArticleDataLogoListResp)
	resp.List = listLogo
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}

// @Title 时间线
// @Description 时间线接口
// @Param   PageSize   query   int  true       "每页数据条数"
// @Param   CurrentIndex   query   int  true       "当前页页码，从1开始"
// @Param   IndustrialManagementId   query   int  false       "产业ID"
// @Success 200 {object} models.TacticsListResp
// @router /timeline [get]
func (this *ReportCommonController) Timeline() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")
	industrialManagementId, _ := this.GetInt("IndustrialManagementId")
	var startSize int
	if pageSize <= 0 {
		pageSize = utils.PageSize20
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}
	startSize = paging.StartIndex(currentIndex, pageSize)
	var total int
	resp := new(models.TacticsListResp)
	page := paging.GetPaging(currentIndex, pageSize, total)
	list := make([]*models.HomeArticle, 0)
	var err error
	list, total, err = models.GetTimeLineReportIndustrialList(industrialManagementId, startSize, pageSize)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取产业报告+晨会点评列表,Err:" + err.Error()
		return
	}
	lenList := len(list)
	for i := 0; i < lenList; i++ {
		item := list[i]
		list[i].Body = ""
		list[i].Abstract, _ = services.GetReportContentTextSub(item.Abstract)
		list[i].Annotation, _ = services.GetReportContentTextSub(item.Annotation)
		list[i].PublishDate = utils.StrTimeToTime(item.PublishDate).Format(utils.FormatDate) //时间字符串格式转时间格式
		//行业比较研究、资金流向，显示报告的摘要
		if resp.MatchTypeName == "行业比较研究" || resp.MatchTypeName == "资金流向" {
			list[i].Annotation = list[i].Abstract
		}
	}
	if len(list) == 0 {
		list = make([]*models.HomeArticle, 0)
	}
	page = paging.GetPaging(currentIndex, pageSize, total)
	resp.List = list
	resp.Paging = page
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}
